@@ -103,7 +103,7 @@ def run_meta_exp(name, config, config_path, command, export_hls, export_ip):
         CommandType.MINIMIZE : run_minimize,
         CommandType.IMPLEMENTATION : run_implement,
     }
-    dispatch[command](exp, pipeline_depth)
+    dispatch[command](exp, latency)
 
 def handle_args(args):
     ini_file = Path(args.exp_file).resolve()
