@@ -56,7 +56,7 @@ def minimize_latency(exp_settings: vivado_exp.Experiment, handlers):
     timings = {cycles: timing}
     up = cycles
     cur_best_timing = timing
-    low = -1
+    low = 1
     while up > low + 1 and cycles != old_cycle:
         old_cycle = cycles
         if cur_best_timing > constraint:
@@ -85,7 +85,7 @@ def minimize_latency(exp_settings: vivado_exp.Experiment, handlers):
         logger.info(f"New interval : [{low},{up}]")
     logger.removeHandler(handler)
 
-    best = up if (low == -1 or timings[low] > constraint) else low
+    best = up if (low == 1 or timings[low] > constraint) else low
     best_timing = timings[best]
 
     return best, best_timing
