@@ -65,6 +65,8 @@ class Experiment:
                  standard: str,
                  hdl: HDL,
                  exp_type: ExperienceType,
+                 pipeline: bool,
+                 ap_ctrl_hs: bool,
                  keep_env: bool = False,
                  description: _opt_str = None,
                  version: _opt_str = None,
@@ -86,10 +88,12 @@ class Experiment:
         self._version = version
         self._logger = logger if logger is not None else logging.getLogger("vrs_log")
         self._hdl = hdl
+        self._ap_ctrl_hs = ap_ctrl_hs
         self._csynth_res = None
         self._syn_impl_res = None
         self._keep_env = keep_env
         self._exp_name = exp_name
+        self._pipeline = pipeline
         self._before_del_lst = []
 
     @property
@@ -121,7 +125,8 @@ class Experiment:
                                 "solution",
                                 self._part,
                                 self._clock_period,
-                                pipeline,
+                                pipeline and self._pipeline,
+                                self._ap_ctrl_hs,
                                 depth_constraint
                                 )
             vtcl.csynth_solution_script(vs)
