@@ -7,7 +7,7 @@ _opt_str = typing.Optional[str]
 
 
 def create_project(file, project_name, filename, comp_name, includes, defines,
-                   standard, solution_name, part, period, pipeline,
+                   standard, solution_name, part, period, pipeline, ctrl_hs,
                    depth_constraint):
     """
     Generate a tcl script for an HLS component creation
@@ -22,6 +22,7 @@ def create_project(file, project_name, filename, comp_name, includes, defines,
     :param defines: list of defines
     :param standard: c++ standard code to use
     :param pipeline: should vivado pipeline the design
+    :param ctrl_hs: should the design be wrapped with ap_ctrl_hs control signals
     :depth_constraint: depth_constraint to set
     """
     file.write("open_project {}\n".format(project_name))
@@ -47,7 +48,8 @@ def create_project(file, project_name, filename, comp_name, includes, defines,
         period
     ))
     file.write('set_clock_uncertainty 0.0 default\n')
-    file.write('set_directive_interface -mode ap_ctrl_none [get_top]\n')
+    ctrl_mode = 'ap_ctrl_hs' if ctrl_hs else 'ap_ctrl_none'
+    file.write(f'set_directive_interface -mode {ctrl_mode} [get_top]\n')
     file.write('config_schedule -relax_ii_for_timing=0 -effort high\n')
     file.write('set_directive_inline -recursive [get_top]\n')
     if pipeline and (depth_constraint is None or depth_constraint > 1):
